Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(473)

Unified Diff: src/uri.js

Issue 7830036: Optimize isFinite and isNaN. (Closed) Base URL: https://v8.googlecode.com/svn/branches/bleeding_edge
Patch Set: Made the change general by moving putting it in the NUMBER_IS_FINITE macro. Created 9 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « src/string.js ('k') | src/v8natives.js » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/uri.js
diff --git a/src/uri.js b/src/uri.js
index c910d756b4c4cdc96336ba49cf0ea25bc3611fb6..72ca6f1565daa2d1b755e73622486afa4e1ddfc5 100644
--- a/src/uri.js
+++ b/src/uri.js
@@ -392,9 +392,8 @@ function URIUnescape(str) {
// -------------------------------------------------------------------
-function SetUpUri() {
- %CheckIsBootstrapping();
- // Set up non-enumerable URI functions on the global object and set
+function SetupURI() {
+ // Setup non-enumerable URI functions on the global object and set
// their names.
InstallFunctions(global, DONT_ENUM, $Array(
"escape", URIEscape,
@@ -406,4 +405,4 @@ function SetUpUri() {
));
}
-SetUpUri();
+SetupURI();
« no previous file with comments | « src/string.js ('k') | src/v8natives.js » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698